/**
 * COOS - Connected Objects Operating System (www.connectedobjects.org).
 *
 * Copyright (C) 2009 Telenor ASA and Tellu AS. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * You may also contact one of the following for additional information:
 * Telenor ASA, Snaroyveien 30, N-1331 Fornebu, Norway (www.telenor.no)
 * Tellu AS, Hagalokkveien 13, N-1383 Asker, Norway (www.tellu.no)
 */
package org.coos.plugin.logback.impl;

import ch.qos.logback.classic.spi.ILoggingEvent;

import ch.qos.logback.core.filter.AbstractMatcherFilter;
import ch.qos.logback.core.spi.FilterReply;

/**
 * A class that filters events depending on their logger name.
 * <p>
 * One can specify a prefix of the logger name and the behaviour of the filter when 
 * the prefix matches the beginning of the logger name of a logging event.
 * <p>
 * By default <code>onMatch</code> is equal to <code>DENY</code> and <code>onMismatch</code> is
 * equal to <code>NEUTRAL</code>.
 * 
 * @author Robert Bj&aelig;rum, Tellu AS
 * 
 */
public class LoggerNamePrefixFilter extends AbstractMatcherFilter<ILoggingEvent> {
	private String prefix;

	public LoggerNamePrefixFilter() {
	}

	@Override
	public void start() {
		setOnMatch(FilterReply.DENY);
		super.start();
	}

	@Override
	public FilterReply decide(ILoggingEvent event) {
		if (!isStarted()) {
			return FilterReply.NEUTRAL;
		}

		if (event.getLoggerName().startsWith(prefix)) {
			return onMatch;
		} else {
			return onMismatch;
		}
	}

	public void setPrefix(String prefix) {
		this.prefix = prefix;
	}

}
